# jupyterlab server

[![Coverage](https://codecov.io/gh/jupyterlab/jupyterlab_server/branch/master/graph/badge.svg)](https://codecov.io/gh/jupyterlab/jupyterlab_server)
[![Build Status](https://github.com/jupyterlab/jupyterlab_server/workflows/Tests/badge.svg?branch=master)](https://github.com/jupyterlab/jupyterlab_server/actions?query=branch%3Amaster+workflow%3A%22Tests%22)
[![Documentation Status](https://readthedocs.org/projects/jupyterlab_server/badge/?version=stable)](http://jupyterlab_server.readthedocs.io/en/stable/)


## Install

`pip install jupyterlab_server`

## Usage

The application author creates a JupyterLab build on their machine
using the core JupyterLab application.  They can then serve their
files by subclassing the `LabServerApp` with the appropriate
configuration and creating a Python entry point that launches the app.


## Contribution

Please see `CONTRIBUTING.md` for details.
